#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 postgresql-libpq
version:              0.9.5.0
visibility:           public
id:                   postgresql-libpq-0.9.5.0-6Abcvnlrbx38D8lE6uFyjU
key:                  postgresql-libpq-0.9.5.0-6Abcvnlrbx38D8lE6uFyjU
license:              BSD-3-Clause
copyright:
    (c) 2010 Grant Monroe
    (c) 2011 Leon P Smith

maintainer:           Oleg Grenrus <oleg.grenrus@iki.fi>
author:               Grant Monroe, Leon P Smith, Joey Adams
homepage:             https://github.com/haskellari/postgresql-libpq
synopsis:             low-level binding to libpq
description:
    This is a binding to libpq: the C application
    programmer'\''s interface to PostgreSQL. libpq is a
    set of library functions that allow client
    programs to pass queries to the PostgreSQL
    backend server and to receive the results of
    these queries.

category:             Database
abi:                  8f0d69fc6a0a8b742b82042d32e1593d
exposed:              True
exposed-modules:
    Database.PostgreSQL.LibPQ Database.PostgreSQL.LibPQ.Internal

hidden-modules:
    Database.PostgreSQL.LibPQ.Compat Database.PostgreSQL.LibPQ.Enums
    Database.PostgreSQL.LibPQ.FFI Database.PostgreSQL.LibPQ.Marshal
    Database.PostgreSQL.LibPQ.Notify Database.PostgreSQL.LibPQ.Oid

import-dirs:          /usr/lib/ghc-9.6.6/site-local/postgresql-libpq-0.9.5.0
library-dirs:
    /usr/lib/ghc-9.6.6/site-local/postgresql-libpq-0.9.5.0 /usr/lib

library-dirs-static:
    /usr/lib/ghc-9.6.6/site-local/postgresql-libpq-0.9.5.0 /usr/lib

dynamic-library-dirs: /usr/lib /usr/lib
data-dir:             /usr/share/haskell-postgresql-libpq
hs-libraries:         HSpostgresql-libpq-0.9.5.0-6Abcvnlrbx38D8lE6uFyjU
extra-libraries:      pq
include-dirs:         /usr/include
depends:              base-4.18.2.1 bytestring-0.11.5.3 unix-2.8.4.0
haddock-interfaces:
    /usr/share/doc/haskell-postgresql-libpq/html/postgresql-libpq.haddock

haddock-html:         /usr/share/doc/haskell-postgresql-libpq/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

